@@ -26,8 +26,6 @@ use crate::wrapper::Wrapper;
 /// for example:
 ///  #[crud_table(table_name:"biz_activity"|table_columns:"id,name,version,delete_flag"|formats_pg:"id:{}::uuid")]
 ///
-/// if use impl CRUDTable for Table struct,
-/// you must impl IdType and id_name() method!
 ///
 pub trait CRUDTable: Send + Sync + Serialize + DeserializeOwned {
     /// is enable use plugin
@@ -760,6 +758,9 @@ pub trait CRUDMut: ExecutorMut {
         where
             T: CRUDTable, C: Serialize + Send + Sync,
     {
+        if column_values.is_empty(){
+            return Ok(vec![]);
+        }
         let w = self.get_rbatis().new_wrapper_table::<T>().in_array(&column, column_values);
         return self.fetch_list_by_wrapper(&w).await;
     }
@@ -948,6 +949,9 @@ impl CRUD for Rbatis {
 
     async fn fetch_list_by_column<T, C>(&self, column: &str, column_values: &[C]) -> Result<Vec<T>> where
         T: CRUDTable, C: Serialize + Send + Sync {
+        if column_values.is_empty() {
+            return Ok(vec![]);
+        }
         let mut conn = self.acquire().await?;
         conn.fetch_list_by_column::<T, C>(column, column_values).await
     }
